@@ -3,7 +3,7 @@ package Class::DBI::ViewLoader;
 use strict;
 use warnings;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 =head1 NAME
 
@@ -70,8 +70,6 @@ use Module::Pluggable (
 use Class::DBI;
 use DBI 1.43;
 
-use UNIVERSAL qw( can isa );
-
 use Carp qw( carp croak confess );
 
 our %handlers = reverse map { /(.*::(.*))/ } __PACKAGE__->plugins();
@@ -213,7 +211,7 @@ sub _load_driver {
     my $handler = $handlers{$driver};
 
     if ($handler) {
-	if (isa($handler, __PACKAGE__)) {
+	if ($handler->isa(__PACKAGE__)) {
 	    # rebless into handler class
 	    bless $self, $handler;
 	}
@@ -911,11 +909,15 @@ sub _do_imports {
 
     my @manual;
     for my $module (@imports) {
-	if (isa($module, 'Exporter')) {
+	# Any non-ref scalar should be a valid class name
+	# We're not interested in other valid invocants
+	next if ref $module;
+
+	if ($module->isa('Exporter')) {
 	    # use Exporter's export method, avoid string eval
 	    $module->export($class);
 	}
-	elsif (can($module, 'import')) {
+	elsif ($module->can('import')) {
 	    push @manual, $module;
 	}
 	else {
